@@ -259,6 +259,15 @@ class Backbone(object):
                 subject.uid = res_data['uid']
             print("##### already create {} {}/{} subject ####".format(subject.name, index, len(subjects)))
 
+    def delete_subject(self, subject_id):
+        """
+        删除科目
+        :param subject_id: 科目id
+        :return:
+        """
+        print(">>> Delete subject")
+        self.nirvana_requester.delete_subject(subject_id)
+
     def create_news(self, news):
         """
         同步新闻信息
