@@ -20,6 +20,22 @@ class ClassroomSync(BaseSync):
         self.building_list = set()
         self.fullname_section = {}
 
+    def get_exist_classroom_map(self):
+        exist_classroom_map = self.client.get_classroom_num_map(self.school_id)
+        return exist_classroom_map
+
+    def cleared_classroom(self):
+        exist_classroom_map = self.get_exist_classroom_map()
+        sql = "SELECT id, areaname, fullname, pid, levf FROM mid_areainfo WHERE updateflag='3' ORDER BY levf"
+        self.cur.execute(sql)
+        rows = self.cur.fetchall()
+        for row in rows:
+            external_id, name, fullname, parent_id, level = row[0], row[1], row[2], row[3], row[4]
+            number = str(external_id)
+            classroom_id = exist_classroom_map.get(number)
+            if classroom_id:
+                self.client.delete_classroom(self.school_id, classroom_id)
+
     def extract_section_map(self):
         sql = "SELECT fullname, dpname FROM mid_term ORDER BY fullname"
         self.cur.execute(sql)
@@ -38,7 +54,7 @@ class ClassroomSync(BaseSync):
             self.building_list.add(parent_id)
 
     def extract_classroom(self):
-        sql = "SELECT id, areaname, fullname, pid, levf FROM mid_areainfo WHERE updateflag='2'  ORDER BY levf"
+        sql = "SELECT id, areaname, fullname, pid, levf FROM mid_areainfo WHERE updateflag='2' ORDER BY levf"
         self.cur.execute(sql)
         rows = self.cur.fetchall()
         for row in rows:
@@ -80,6 +96,7 @@ class ClassroomSync(BaseSync):
             return [(name, number)]
 
     def sync(self):
+        self.cleared_classroom()
         self.extract_building()
         self.extract_classroom()
         if not self.classroom_map:
