@@ -87,7 +87,7 @@ class CourseSync(BaseSync):
         double_number_map = self.get_double_map()
         today, last_day = self.get_date_range()
         today, last_day = "2020-11-02", "2020-11-08"
-        sql = "SELECT id, coursename, sectionid, classroomid, coursedate, weekday, userid, isteacher, deptname " \
+        sql = "SELECT id, coursename, sectionid, classroomid, coursedate, weekday, userid, isteacher, deptname, outid " \
               "FROM mid_attendschedule " \
               "WHERE updateflag!='3' and coursedate > '{}' and coursedate <= '{}' and deptname!='学生' " \
               "ORDER BY weekday".format(today, last_day)
@@ -97,7 +97,7 @@ class CourseSync(BaseSync):
             category = TableCategory.ALL
             attend_id, subject_name, slot_id = row[0], row[1], row[2]
             classroom_id, course_date, week = row[3], row[4], row[5]
-            user_id, is_teacher, class_name = row[6], row[7], row[8]
+            user_id, is_teacher, class_name, user_number = row[6], row[7], row[8], row[9]
             # unique_key = "{}_{}".format(subject_name, classroom_id)
             subject_number = get_md5_hash(subject_name)
             num = self.slot_map.get(slot_id, None)
@@ -105,8 +105,6 @@ class CourseSync(BaseSync):
                 print("Can't Find SlotID {}".format(slot_id))
                 continue
             current_course_table = self.slot_course_table.get(slot_id)
-            if current_course_table[0] in ["M", "U"]:
-                print(current_course_table)
             if not current_course_table:
                 print("Can't Find SlotID {}".format(slot_id))
                 continue
@@ -140,11 +138,11 @@ class CourseSync(BaseSync):
                 if is_teacher:
                     if str(user_id) in ["1", "4"]:
                         continue
-                    teacher_number = self.teacher_map.get(user_id)
+                    teacher_number = user_number
                     if teacher_number:
                         course.teacher_number = teacher_number
                 else:
-                    student_number = self.student_map.get(user_id)
+                    student_number = user_number
                     if student_number:
                         course.add_student(student_number)
                     class_name = self.student_section_map.get(student_number)
@@ -153,18 +151,6 @@ class CourseSync(BaseSync):
                         if exist_class_sign and current_course_table != exist_class_sign:
                             print("该班级{}已在{}课表出现，请检查数据".format(class_name, exist_class_sign))
                             continue
-                        if "E" in current_course_table and "小学" not in class_name:
-                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, current_course_table))
-                            print(attend_id)
-                            continue
-                        if "M" in current_course_table and "初中" not in class_name:
-                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, current_course_table))
-                            print(attend_id)
-                            continue
-                        if "U" in current_course_table and "高中" not in class_name:
-                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, current_course_table))
-                            print(attend_id)
-                            continue
                         self.class_set[current_course_table].add(self.class_name_num[class_name])
                         self.class_sign[class_name] = current_course_table
                 course.add_position(num, week, category, classroom_number)
