@@ -27,10 +27,10 @@ class MeetingRoomSync(BaseSync):
         self.classroom_fullname_name = {}
 
     def get_double_map(self):
-        double_number = {"1": ["1_A", "1_B"],
-                         "2": ["2_A", "2_B"],
-                         "3": ["3_A", "3_B"],
-                         "4": ["4_A", "4_B"]}
+        double_number = {"1xx": ["1_A", "1_B"],
+                         "2xx": ["2_A", "2_B"],
+                         "3xx": ["3_A", "3_B"],
+                         "4xx": ["4_A", "4_B"]}
         return double_number
 
     def extract_classroom_info(self):
@@ -134,9 +134,9 @@ class MeetingRoomSync(BaseSync):
             apply_date = str2datetime(apply_date[:19])
             start_date = str2datetime(start_date[:19])
             end_date = str2datetime(end_date[:19])
-            place_name = self.classroom_fullname_name.get(place_name)
-            if not place_name:
-                continue
+            # place_name = self.classroom_fullname_name.get(place_name)
+            # if not place_name:
+            #     continue
             classroom_numbers = double_number_map.get(place_id, [place_id])
             for classroom_number in classroom_numbers:
                 place_num = self.add_meeting_place(place_name, number=classroom_number)
