@@ -12,9 +12,14 @@ class SubjectSync(BaseSync):
         self.offset = 300
         self.subject_map = {}
 
+    def clear_subjects(self):
+        subject_num_map = self.client.get_subject_num_map(self.school_id)
+        for subject_id in list(subject_num_map.values()):
+            self.client.delete_subject(self.school_id, subject_id)
+
     def extract_subject(self):
         today, last_day = self.get_date_range()
-        today, last_day = '2020-09-02', '2020-10-11'
+        today, last_day = "2020-11-02", "2020-11-08"
         sql = "SELECT DISTINCT coursedetailid, coursename FROM mid_attendschedule " \
               "WHERE coursedate > '{}' and coursedate <= '{}' ORDER BY coursedetailid".format(today, last_day)
         self.cur.execute(sql)
@@ -26,6 +31,7 @@ class SubjectSync(BaseSync):
             self.subject_map[number] = subject
 
     def sync(self):
+        self.clear_subjects()
         self.extract_subject()
         if not self.subject_map:
             logger.info("没有科目信息")
