@@ -211,7 +211,7 @@ class CourseTableSync(BaseSync):
                 course = Course(number=course_number, name=course_name[:63], teacher_number=teacher_number,
                                 classroom_number=classroom_num, subject_number=subject_number,
                                 begin_week=time_result['begin_week'], end_week=time_result['end_week'],
-                                required_student=False, is_present=False)
+                                required_student=False, is_present=True)
                 self.course_map[course_name] = course
             for position in time_result['positions']:
                 course.add_position(position[0], position[1], time_result['single'])
@@ -273,7 +273,7 @@ class CourseTableSync(BaseSync):
                     if subject_number not in self.subject_map:
                         self.add_subject(subject_name, subject_number, subject_info['ori_num'])
                     course = Course(number=course_number, name=course_name[:63], teacher_number=teacher_number,
-                                    classroom_number=classroom_num, subject_number=subject_number, is_present=False,
+                                    classroom_number=classroom_num, subject_number=subject_number, is_present=True,
                                     begin_week=begin_week, end_week=end_week, required_student=False)
                     self.course_map[course_name] = course
 
@@ -443,7 +443,7 @@ class CourseTableSync(BaseSync):
                 else:
                     course_number = get_md5_hash(course_name)
                     course_data = dict(number=course_number, name=course_name[:63], classroom_number=classroom_num,
-                                       subject_number=subject_number, is_present=False, begin_week=begin_week,
+                                       subject_number=subject_number, is_present=True, begin_week=begin_week,
                                        end_week=end_week, required_student=False)
                     if teacher_number:
                         course_data[teacher_number] = teacher_number
